
% compute generalized eigen-values

clear

debug=0; % 2: debug on small size , 0: full size
datafiledir='';

% -- load data
loadstr=["load " datafiledir "snvdatacenter.mat"];
eval(loadstr);
clear snvdatafc snvdatawc

% -- debug with small size kernel
if debug==2
  [ncol,nfile]=size(snvdatac);
  nhalf=round(ncol/2);
  deltan=200;
  snvdatac=snvdatac(nhalf+(-deltan:deltan),:);
end;

[ncol,nfile]=size(snvdatac);

% -- whiten and over-whiten data

nf=2^(nextpow2(ncol));
psd=zeros(nf,1);
acftmp=zeros(nf,1);
f=(0:nf/2)/nf*fs;

% use of official Virgo sensitivity
% .5 factor because the given curve is one sided
psd(1:nf/2+1)=.5*(9e-37./f.^5+4.5e-43./f+3.24e-46*(1+(f/500).^2));
psd(1)=psd(2); % remove singularity @DC
psd(nf/2+2:nf)=flipud(psd(2:nf/2));
acftmp=fs*real(ifft(psd));

hnoisef=sqrt(psd);
wfilter=fs*real(ifft(hnoisef));

acf=acftmp(1:ncol);

clear psd acftmp

fprintf('computing noise corr matrix...');
fflush(1);
R=toeplitz(acf);
fprintf(' done.\n');

% -- cholesky
fprintf('computing cholesky...');
fflush(1);
g=chol(R);
fprintf(' done.\n');
if debug<2
  clear R;
end;
fprintf('computing inverse...');
fflush(1);
g=inv(g);
fprintf(' done.\n');

% -- compute covariance matrix
fprintf('computing signal cov matrix...');
fflush(1);
C=zeros(ncol,ncol);
for icol=1:nfile,
    x=snvdatac(:,icol);
    C=C+x*x';
end;
C=C/nfile;
fprintf(' done.\n');

clear snvdatac

% -- schur
fprintf('computing schur...');
fflush(1);
[q d]=schur(g'*C*g);
if debug<2
  clear C
end;
fprintf(' done.\n');

[evg idx]=sort(diag(d));
clear d

fprintf('computing eigen vectors...');
fflush(1);
evect=g*q;
fprintf(' done.\n');

% -- pick up first and second vector
s1=evect(:,idx(ncol));
s2=evect(:,idx(ncol-1));
s3=evect(:,idx(ncol-2));
s4=evect(:,idx(ncol-3));

% -- write output file
if debug>0
  fprintf('writing snvdataeig.mat...');
  fflush(1);
end;

eval(["save -mat-binary " datafiledir "snvdataeig.mat s1 s2 evg fs"]);

if debug>0
  fprintf(' done.\n');
  fflush(1);
end;





