
% FIGURE 1
% generate sample figure of some selected wvfs
 
clear
 
% -- set plot context

graw('reset;set data style lines;') 
gset term x11
gset nokey
gset lmargin 7;
gset rmargin 4;
       
debug=0; % 1: x11, 0: postscript
datafiledir=''

% -- load data
eval(["load " datafiledir "snvdatacenter.mat"]);

% -- define distance to snv where you'd like to place your test wvf
d=20;                      % distance in kpc
d0=1000;                   % kpc, wvf have been computed @1Mpc=1000kpc 
d1=d0*mean(snr);           % distance at which snr=1      
dref=d0*mean(norm_coef);   % current distance of all snvdata(.,f,w)c waveforms
snrdref=d0/dref*mean(snr);  % snr at ref. distance 
snrd=d0/d*mean(snr);       % optimal snr @ dist d
dref2d=dref/d;

fprintf('distance with snr=1: %f kpc \n',d1);
fprintf('ref. distance to snv= %f kpc, [ampl opt] snr = %f\n',dref,snrdref);
fprintf('current distance to snv= %f kpc, [ampl opt] snr = %f\n',d,snrd);

[ncol nfile]=size(snvdatafc);

typeindex=[5 7 6];

if debug==0
  gset term posts eps enhanced color dashed "helvetica" 14
  gset output "figure1.eps";
end;  

x1=dref2d*snvdatac(:,typeindex(1));
y1=dref2d*snvdatawc(:,typeindex(1));

x2=dref2d*snvdatac(:,typeindex(2));
y2=dref2d*snvdatawc(:,typeindex(2));

x3=dref2d*snvdatac(:,typeindex(3));
y3=dref2d*snvdatawc(:,typeindex(3));

nf=2^(nextpow2(ncol));
tc=find(y1==min(y1));
t=(-tc:(ncol-tc-1))/fs;

% -- compute Fourier transform of snv signal
xbuf=[x1;zeros(nf-ncol,1)];
xbuf=xbuf-mean(xbuf);
x1f=abs(fft(xbuf)/fs);

xbuf=[x2;zeros(nf-ncol,1)];
xbuf=xbuf-mean(xbuf);
x2f=abs(fft(xbuf)/fs);

xbuf=[x3;zeros(nf-ncol,1)];
xbuf=xbuf-mean(xbuf);
x3f=abs(fft(xbuf)/fs);

% -- compute Fourier transform of snv whiten signal
ybuf=[y1;zeros(nf-ncol,1)];
y1f=abs(fft(ybuf)/fs);

ybuf=[y2;zeros(nf-ncol,1)];
y2f=abs(fft(ybuf)/fs);

ybuf=[y2;zeros(nf-ncol,1)];
y3f=abs(fft(ybuf)/fs);

ubw=1000; % useful bandwidth=1kHz
  
% -- use of official Virgo sensitivity
f=(0:nf/2)/nf*fs;
psd=zeros(nf/2+1,1);
% .5 factor because the given curve is one sided
psd(1:nf/2+1)=.5*(9e-37./f.^5+4.5e-43./f+3.24e-46*(1+(f/500).^2));
psd(1)=psd(2); % remove singularity @DC

index=(1:2:nf/2+1);

% -- plotting...
multiplot(3,2);

subplot(3,2,1);
  plot(t*1e3,y1);
  ylabel('whiten h(t)');
  xlabel('time (ms)');
  eval(sprintf('title("(a) snv at %d kpc, snr=%2.1f")',d,snrd));  

subplot(3,2,2);
  loglog(f(2:nf/2+1),sqrt(ubw)*x1f(2:nf/2+1));
  hold on;
  loglog(f(index),sqrt(psd(index)),'--');
  hold off;
  ylabel('ampl. spect. [u/sqrt(Hz)]');
  xlabel('frequency (Hz)');
  title('(b)');
    
subplot(3,2,3); 
  plot(t*1e3,y2);
  hold off;
  ylabel('whiten h(t)');
  xlabel('time (ms)');
  eval(sprintf('title("(c) snv at %d kpc, snr=%2.1f")',d,snrd));  

subplot(3,2,4);
  loglog(f(2:nf/2+1),sqrt(ubw)*x2f(2:nf/2+1));
  hold on;
  loglog(f(index),sqrt(psd(index)),'--');
  hold off;
  ylabel('ampl. spect.');
  xlabel('frequency (Hz)');
  title('(d)');

subplot(3,2,5); 
  plot(t*1e3,y3);
  hold off;
  ylabel('whiten h(t)');
  xlabel('time (ms)');
  eval(sprintf('title("(e) snv at %d kpc, snr=%2.1f")',d,snrd));  

subplot(3,2,6);
  loglog(f(2:nf/2+1),sqrt(ubw)*x3f(2:nf/2+1));
  hold on;
  loglog(f(index),sqrt(psd(index)),'--');
  hold off;
  ylabel('ampl. spect.');
  xlabel('frequency (Hz)');
  title('(f)');
  
% -- relax
oneplot();
gset autoscale x
gset autoscale y
gset term x11
          



