
% FIGURE 2
% plot eigen-values of H computed with all wvf + zoom
% plot first two eigen-vectors

clear

% -- set plot context

graw('reset;set data style lines;set pointsize .2;') 
gset term x11
gset nokey
gset lmargin 9;
gset rmargin 1;

debug=0; %  1: x11, 0: postscript
datafiledir='';

% -- load data
eval(["load " datafiledir "snvdataeig.mat"]);

[ncol ncls]=size(s1);
tc=find(s1==min(s1));
t=(-tc:(ncol-tc-1))/fs;
nevgmax=10;

nf=2^(nextpow2(ncol));
f=fs*(0:nf/2-1)/nf;

% -- compute spectrum of first and second vectors
s1f=fft([s1;zeros(nf-ncol,1)]);
s2f=fft([s2;zeros(nf-ncol,1)]);
sfmax=max(abs([s1f;s2f]));

if debug==0
  gset term posts eps enhanced color dashed "helvetica" 18
  gset output "figure2.eps";
end;  

% -- plotting...
multiplot(2,2);

subplot(221);
gset xrange [1:100];
gset xtics 0,20,100
semilogy(flipud(evg(1:ncol)));
title('(a) eigen values of H');
xlabel('index');
ylabel('eigen value');

% relax
gset xtics autofreq
gset ytics autofreq
gset autoscale x
gset autoscale y

subplot(222);
grid("on");
perf=cumsum(flipud(evg(1:ncol)).^2);
perf=perf./perf(ncol);
plot(perf(1:10));
title('(b) ');
xlabel('eigen value index');
ylabel('normal. deflection');
gset xrange [1:10];
gset ytics 0.9,.02,1;
  
% relax 
gset autoscale x
gset autoscale y

subplot(223);
title('(c) eigen vect. 0 and 1');
xlabel('time (ms)');
ylabel('amplitude x10^{20}');
eval(sprintf('gset xrange [%f:%f]',-10,15));
gset xtics -10,5,15;
gset ytics -1,.2,1
grid
plot(t*1e3,s1*1e-20);
hold on
plot(t*1e3,s2*1e-20,'--');
hold off

% relax
gset xtics autofreq
gset ytics autofreq
gset autoscale x
gset autoscale y

subplot(224);
gset xrange [0:2000]
gset xtics 0,1000,2000
eval(sprintf('gset yrange [%f:%f]',0,sfmax*1e-20));
title('(d)');
xlabel('frequency (Hz)');
ylabel('ampl. spec. x10^{20}');
plot(f,abs(s1f(1:nf/2))*1e-20);
hold on
plot(f,abs(s2f(1:nf/2))*1e-20,'--');
hold off

% -- relax
oneplot();
gset autoscale x
gset autoscale y
gset term x11


