
% load and put all DFM waveforms (RAW data) into a single matrix
% save result into a MAT file

% you need to download the DFM waveforms first
% http://www.mpa-garching.mpg.de/rel_hydro/axi_core_collapse/

% -- init

clear

% put your path here
infiledir='../rawdata/';
outfiledir='';

fs=20e3; % sampling freq. kHz
msec=1e-3; % millisec

nm=0;
nmax=4096;    % maxsize of signal
nfile=25;

% conversion to strain signal
theta=pi/2; % assume obs in equatorial plane
r=1000; % distance in kpc
kpc=3e21; % cm=1 kpc
c=sqrt(15/pi)/8*(sin(theta))^2/(r*kpc);

snvdata=zeros(nmax,nfile);
cfile=1;

% -- main loop

for icol=1:4,
  for jcol=1:5,	
    for kcol=1:5,
      data=['signal_A' num2str(icol) 'B' num2str(jcol) 'G' num2str(kcol) '_R'];
      namefile=[infiledir data '.dat'];
      
      if exist(namefile)==2,
	printf('reading file #%d: %s\n',cfile,data);
	eval(['load ' namefile ';']);
	eval(['t= ' data '(:,1);']);
	eval(['x= ' data '(:,2);']);
	xmax=max(x);
	tmin=t(min(find(x>(1e-5*xmax))));
	tmax=max(t);
	n=round((tmax-tmin)*msec*fs);
	ti=tmin+(0:n-1)/(msec*fs);
	xi=c*interp1(t,x,ti);
	xi=xi-xi(1); % remove DC
	printf('check -- orig, max:%1.1e min:%1.1e, interp, max:%1.1e min:%1.1e \n',c*max(x),c*min(x),max(xi),min(xi));
      
	if n<=nmax
	  snvdata(1:n,cfile)=xi';
	  snvdata(n+1:nmax,cfile)=snvdata(n,cfile)*ones(nmax-n,1);
        else
	  snvdata(:,cfile)=xi(n-nmax+1:n);
          sumtest=sum(abs(xi(1:n-nmax)));
          if (abs(sumtest)>1e-2*sum(xi))
            sumtest 
            error('waveform cannot fit in nmax data points');
          end;
        end;
	eval(['clear t x ti xi ' data]);
	cfile=cfile+1;
        nm=max(n,nm);
        % printf('%d %d\n',n,nm);
	fflush(1);
      end

    end;
  end;
end;

printf('signal max size = %d, dt=%1.2f ms\n',nm,nm/(msec*fs));
printf('%d files read\n',cfile-1);

% -- writing output
if (cfile>1)
       eval(["save -mat-binary " outfiledir "snvdata.mat snvdata fs"]);
       printf("wrote snvdata.mat\n");
else
       printf("no data found\n");
end;